@@ -1,7 +1,7 @@
 package Getopt::Long::Complete;
 
-our $DATE = '2016-10-22'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2016-12-03'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,6 +89,8 @@ sub GetOptionsWithCompletion {
     require Getopt::Long;
     my $old_conf = Getopt::Long::Configure(
         'no_ignore_case',
+        'no_getopt_compat',
+        'gnu_compat',
         $opt_bundling ? 'bundling' : 'no_bundling',
         $opt_permute ? 'permute' : 'no_permute',
         $opt_pass_through ? 'pass_through' : 'no_pass_through',
@@ -120,7 +122,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.28 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2016-10-22.
+This document describes version 0.29 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2016-12-03.
 
 =head1 SYNOPSIS
 
@@ -254,8 +256,10 @@ Will call Getopt::Long's GetOptions, except when COMP_LINE environment variable
 is defined, in which case will print completion reply to STDOUT and exit.
 
 B<Note: Will temporarily set Getopt::Long configuration as follow: bundling,
-no_ignore_case. I believe this a sane default.> You can turn off bundling via
-C<$opt_bundling>.
+no_ignore_case, gnu_compat, no_getopt_compat, permute (if POSIXLY_CORRECT
+environment is false). I believe this a sane default.> You can turn off bundling
+via C<$opt_bundling>. You can turn on/off permute explicitly by via
+C<$opt_permute>. You can turn on pass_through via C<$opt_pass_through>.
 
 =head2 GetOptionsWithCompletion(\&completion, [\%hash, ]@spec)
 
